@@ -66,7 +66,9 @@ def _test_server_and_api(server, api_key, insecure, ca_cert):
     me = None
 
     with cli_feedback('Checking %s' % server):
-        real_server, _ = test_server(api.RSConnectServer(server, api_key, insecure, ca_data))
+        real_server, _ = test_server(api.RSConnectServer(server, None, insecure, ca_data))
+
+    real_server.api_key = api_key
 
     if api_key:
         with cli_feedback('Checking API key'):
@@ -299,7 +301,8 @@ def _validate_deploy_to_args(name, url, api_key, insecure, ca_cert, api_key_is_r
     # If our info came from the command line, make sure the URL really works.
     if not from_store:
         connect_server, _ = test_server(connect_server)
-        connect_server.api_key = api_key
+
+    connect_server.api_key = api_key
 
     if not connect_server.api_key:
         if api_key_is_required:
